Delaware State Courts Opinions and Orders

Courts

Courts

Courts

Citizen Help

Citizen Help

Citizen Help

Opinions

Opinions

Opinions

Calendars

Calendars

Calendars

Forms

Forms

Forms

Rules

Rules

Rules

Jury

Jury

Jury

eFiling

eFiling

eFiling

Non-Judicial Agencies

Non-Judicial Agencies

Non-Judicial Agencies

General Information

General Information

General Information

home | feedback |
| Search:

All Courts
› | Civil
› | Criminal
Supreme
› | Civil
› | Criminal
Chancery
Superior
› | CCLD
› | Civil
› | Criminal
Common Pleas
› | Civil
› | Criminal
Justice of the Peace
| Get Acrobat Reader
Court Of Chancery Opinions and Orders
Please note: These electronic orders may contain computer-generated errors or other deviations from the official printed versions. In case of discrepancies between the print and electronic versions of orders, the print version controls. In case of discrepancies between the print and electronic versions of orders and any later official version of them, the later version controls. Please also note: There are currently issues with some of the documents not opening when using the Chrome browser. If you cannot open a document and are using Chrome, please try using a different browser.
| Year: | Open Document in New Window |
Search For: |  |
129 files found, based on group and search criteria.
1 2 3
Date | Parties/Caption | Number | Court | Judicial Officer* | Description
7/29/14 | Augustus Evans, Jr. vs. Bayer Corporation | CM# 05468-N(UASSIGNED) | Chancery | Glasscock V.C. | Letter Opinion
7/29/14 | Augustus Evans, Jr. vs. Johnson & Johnson Co. | CM #05468-N (UNASSIGNED) | Chancery | Glasscock V.C. | Letter Opinion
7/29/14 | Hardy v. Hardy, et al. | CA #7531-VCP | Chancery | Parsons V.C. | Memorandum Opinion
7/28/14 | RCM LSW II, LLC v. Lincoln Circle Assocaites, LLC et al. | C.A. #9478-VCL | Chancery | Laster V.C. | Memorandum Opinion
7/24/14 | In re Ebix, Inc. Stockholder Litigation | CA #8526-VCN | Chancery | Noble V.C. | Memorandum Opinion
7/22/14 | Arthur V. Belendiuk v. Richard L. Carrion et al. & Verizon Communications Inc. et al. | C.A. #9026-ML | Chancery | M. LeGrow | Master's Final Report
7/22/14 | Cook v. Whitman | CA # 9458-VCG | Chancery | Glasscock V.C. | Letter Opinion
7/22/14 | MPT of Hoboken Trs, LLC v. HUMC Holdco, LLC | CA #8442-VCN | Chancery | Noble V.C. | Memorandum Opinion and Order
7/21/14 | Andrew Durham v. Grapetree LLC | CA # 7325-VCG | Chancery | Glasscock V.C. | Letter Opinion
7/21/14 | Bishop Macram Max Gassis, et al. v. Neil Corkery, et al. | CA #8868-VCG | Chancery | Glasscock V.C. | Letter Opinion
7/21/14 | Comerica Bank v. Global Payments Direct, Inc., et al. | CA #9707-CB | Chancery | Bouchard C. | Memorandum Opinion and Order
7/21/14 | Matthew v. Laudamiel | CA #5957-VCN | Chancery | Noble V.C. | Letter Opinion
7/17/14 | CARTER FARM, LLC, a Delaware Limited Liability Co., vs. NEW CASTLE COUNTY, a political subdivision of the State of DE | CA #1641-VCG | Chancery | Glasscock V.C. | Memorandum Opinion and Order
7/16/14 | Julie Friedman v. Dara Khosrowshahi, et al. | CA #9161-CB | Chancery | Bouchard C. | Memorandum Opinion
7/15/14 | Wells Fargo Bank, NA v. Earl Strong | CA #8538-MA | Chancery | Ayvazian M. | Master's Final Report
7/14/14 | Agnieszka and Marek Kostyszyn v. Gianmarco and Gilda Martuscelli, the Estate of Brett J. Harris, Frozen Endeavors, Inc., AJT, Inc., and Chesapeake Inn, Inc. | CA #8828-MA | Chancery | Ayvazian M. | Master's Final Report
7/14/14 | Dixon v. Joyner; Letha D. Copeland Estate | C.A. #7452-ML; ROW #149218 | Chancery | M. LeGrow | Master's Final Report
7/3/14 | CCC Atlantic, LLC v. Grey, Joseph | CA #8739-VCN | Chancery | Noble V.C. | Letter Opinion
7/1/14 | Alan L. Lucas, et al v. Alan Hanson, et al. | C.A. #9424-ML | Chancery | M. LeGrow | Master's Final Report
6/30/14 | Branin v. Stein Roe Investment Counsel, LLC, et al. | CA #8481-VCN | Chancery | Noble V.C. | Memorandum Opinion and Order
6/30/14 | Capano, Gerard J. v. Capano, Louis J., Jr., et al. | CA #8767-VCN | Chancery | Noble V.C. | Memorandum Opinion
6/30/14 | Capano, Joseph M., et al. v. Capano, Louis J., Jr., et al. | CA #8721-VCN | Chancery | Noble V.C. | Memorandum Opinion
6/30/14 | Dent v. Ramtron | CA #7950-VCP | Chancery | Parsons V.C. | Memorandum Opinion
6/30/14 | IMO: The Estate of Paulina duPont Dean | C.A. #7430-ML | Chancery | M. LeGrow | Master's Final Report
6/30/14 | Xcell Energy and Coal Company, LLC v. Energy Investment Group, LLC | CA #8652-VCN | Chancery | Noble V.C. | Letter Opinion
6/27/14 | Brevan Howard Credit Catalyst Master Fund Limited, et al. v. Spanish Broadcasting System, Inc. | CA #9209-VCG | Chancery | Glasscock V.C. | Memorandum Opinion
6/27/14 | Wayman Fire Protection, Inc. v. Premium Fire & Security, LLC | CA #7866-VCP | Chancery | Parsons V.C. | Letter Opinion
6/26/14 | Cambridge Retirement System v. Slavko James Joseph Bosnjak, et al. | CA #9178-CB | Chancery | Bouchard C. | Memorandum Opinion
6/25/14 | Laidler v. Hesco Bastion Environmental, Inc. | CA #7561-VCG | Chancery | Glasscock V.C. | Letter Opinion
6/25/14 | Meso Scale Diagnostics, LLC v. Roche Diagnostics GmbH, et al. | CA #5589-VCP | Chancery | Parsons V.C. | Memorandum Opinion
6/20/14 | Allen v. El Paso Pipeline GP Company, L.L.C., et al. | CA #7520-VCL | Chancery | Laster V.C. | Memorandum Opinion
6/20/14 | David Raul v. Astoria Financial Corporation | CA #9169-VCG | Chancery | Glasscock V.C. | Memorandum Opinion and Order
6/16/14 | In re TriQuint Semiconductor, Inc. Stockholders Litigation | CA #9415-VCN | Chancery | Noble V.C. | Letter Opinion
6/12/14 | In Re: El Paso Pipeline Partners, L.P. Derivative Litigation | CA #7141-VCL | Chancery | Laster V.C. | Memorandum Opinion
6/12/14 | Sequoia Presidential Yacht Group LLC v. FE Partners, LLC | CA #8270-VCG | Chancery | Glasscock V.C. | Letter Opinion
6/11/14 | Donna F. Miller v. National Land Partners,LLC, et al. | CA #7977-VCG | Chancery | Glasscock V.C. | Memorandum Opinion
6/5/14 | Al Jazeera America LLC v. AT&T Services, Inc. | CA #8823-VCG | Chancery | Glasscock V.C. | Letter Opinion
6/4/14 | IMO Restatement of Declaration of Trust Creating the Survivor's Trust Created Under the Ravet Family Trust | CA #7743-VCG | Chancery | Glasscock V.C. | Letter Opinion
6/3/14 | In re Appraisal of NetSpend Holdings, Inc. | CA #8807-VCG | Chancery | Glasscock V.C. | Letter Opinion
5/30/14 | Eurofins Panlabs, Inc. v. Ricerca Biosciences, LLC, et al. | CA #8431-VCN | Chancery | Noble V.C. | Memorandum Opinion
5/30/14 | Sustainable Energy v. Photon Energy, et al. | CA #8524-VCP | Chancery | Parsons V.C. | Memorandum Opinion
5/30/14 | The Ravenswood Investment Company, L.P. v. Winmill & Co. Incorporated | CA #7048-VCN | Chancery | Noble V.C. | Letter Opinion
5/30/14 | Thomas A. Rizk et al v. TractManager, Inc. | C.A. #9073-ML | Chancery | M. LeGrow | Master's Final Report
5/29/14 | Delaware Building & Construction Trades Council, AFL-CIO v. The University of Delaware, et al. | CA #7881-VCG | Chancery | Glasscock V.C. | Letter Opinion
5/29/14 | In re: Westech Capital Corp. | CA #8845-VCN | Chancery | Noble V.C. | Memorandum Opinion
5/29/14 | Mickael A. Flaa v. Daniel C. Montano, et al. | CA #9146-VCG | Chancery | Glasscock V.C. | Memorandum Opinion
5/29/14 | Pontone v. Milso Industries Corporation, et al. | CA #7615-VCP | Chancery | Parsons V.C. | Memorandum Opinion
5/28/14 | Bishop Macram Max Gassis, et al. v. Neil Corkery, et al. | CA #8868-VCG | Chancery | Glasscock V.C. | Memorandum Opinion
5/22/14 | Oracle Partners, L.P. v. Biolase, Inc. | CA #9438-VCN | Chancery |  | Memorandum Opinion
5/21/14 | MidAtlantic Farm Credit, ACA v. Ronald W. Morgan and Ronald J. Morgan | C.A. #5985-ML | Chancery | M. LeGrow | Master's Final Report
1 2 3
* C.=Chancellor or Commissioner; C.J.=Chief Justice or Chief Judge; J.=Justice or Judge; M.=Master; P.J.=President Judge; R.J.=Resident Judge; V.C.=Vice Chancellor
send an email containing a hyperlink to the selected document
| Year: | Open Document in New Window |
Search For: |  |